@@ -7,7 +7,7 @@
 # Like what you see? Join us!
 # https://www.univention.com/about-us/careers/vacancies/
 #
-# Copyright 2004-2023 Univention GmbH
+# Copyright 2004-2024 Univention GmbH
 #
 # https://www.univention.de/
 #
@@ -45,7 +45,7 @@ import Crypto
 import heimdal
 import ldap
 import samba.dcerpc.samr
-from Crypto.Cipher import ARC4, DES
+from Crypto.Cipher import ARC4, DES  # noqa: S413
 from samba import NTSTATUSError
 from samba.dcerpc import drsblobs, drsuapi, lsa, misc, security
 from samba.ndr import ndr_unpack
@@ -58,7 +58,7 @@ def nt_password_to_arcfour_hmac_md5(nt_password):
     # all arcfour-hmac-md5 keys begin this way
     key = b'0\x1d\xa1\x1b0\x19\xa0\x03\x02\x01\x17\xa1\x12\x04\x10'
 
-    for i in range(0, 16):
+    for i in range(16):
         o = nt_password[2 * i:2 * i + 2]
         key += chr(int(o, 16)).encode('ISO8859-1')
     return key
@@ -89,8 +89,8 @@ def mySamEncryptNTLMHash(hash, key):
     Key1 = transformKey(Key1)
     Key2 = key[7:14]
     Key2 = transformKey(Key2)
-    Crypt1 = DES.new(Key1, DES.MODE_ECB)
-    Crypt2 = DES.new(Key2, DES.MODE_ECB)
+    Crypt1 = DES.new(Key1, DES.MODE_ECB)  # noqa: S304
+    Crypt2 = DES.new(Key2, DES.MODE_ECB)  # noqa: S304
     plain1 = Crypt1.encrypt(Block1)
     plain2 = Crypt2.encrypt(Block2)
     return plain1 + plain2
@@ -111,8 +111,8 @@ def deriveKey(baseKey):
 
 def removeDESLayer(cryptedHash, rid):
     Key1, Key2 = deriveKey(rid)
-    Crypt1 = DES.new(Key1, DES.MODE_ECB)
-    Crypt2 = DES.new(Key2, DES.MODE_ECB)
+    Crypt1 = DES.new(Key1, DES.MODE_ECB)  # noqa: S304
+    Crypt2 = DES.new(Key2, DES.MODE_ECB)  # noqa: S304
     decryptedHash = Crypt1.decrypt(cryptedHash[:8]) + Crypt2.decrypt(cryptedHash[8:])
     return decryptedHash
 
@@ -146,7 +146,7 @@ def decrypt_history(key, data, rid):
 
 def calculate_krb5keys(supplementalCredentialsblob):
     spl = supplementalCredentialsblob
-    #cleartext_hex = None
+    # cleartext_hex = None
     keys = []
     keytypes = []
     kvno = 0
@@ -159,7 +159,7 @@ def calculate_krb5keys(supplementalCredentialsblob):
 
     krb5_old_hex = None
 
-    for i in range(0, spl.sub.num_packages):
+    for i in range(spl.sub.num_packages):
         pkg = spl.sub.packages[i]
         if pkg.name != "Primary:Kerberos":
             continue
@@ -186,7 +186,7 @@ def calculate_krb5keys(supplementalCredentialsblob):
 
     krb5_new_hex = None
 
-    for i in range(0, spl.sub.num_packages):
+    for i in range(spl.sub.num_packages):
         pkg = spl.sub.packages[i]
         if pkg.name != "Primary:Kerberos-Newer-Keys":
             continue
@@ -231,7 +231,7 @@ def set_password_in_ad(connector, samaccountname, pwd, reconnect=False):
     try:
         sam_accountname = lsa.String()
         sam_accountname.string = samaccountname
-        (rids, types) = connector.samr.LookupNames(connector.dom_handle, [sam_accountname])
+        (rids, _types) = connector.samr.LookupNames(connector.dom_handle, [sam_accountname])
 
         rid = rids.ids[0]
         user_handle = connector.samr.OpenUser(connector.dom_handle, security.SEC_FLAG_MAXIMUM_ALLOWED, rid)
@@ -296,7 +296,7 @@ def get_password_from_ad(connector, user_dn, reconnect=False):
     req8.fsmo_info = 0
 
     while True:
-        (level, ctr) = connector.drs.DsGetNCChanges(connector.drsuapi_handle, 8, req8)
+        (_level, ctr) = connector.drs.DsGetNCChanges(connector.drsuapi_handle, 8, req8)
         rid = None
         unicode_blob = None
         history_blob = None
@@ -400,10 +400,10 @@ def password_sync_ucs(connector, key, object):
 
     pwd_set = False
     try:
-        nt_hash, krb5Key, _ = get_password_from_ad(connector, object['dn'])
+        nt_hash, _krb5Key, _ = get_password_from_ad(connector, object['dn'])
     except NTSTATUSError as exc:
         ud.debug(ud.LDAP, ud.PROCESS, "password_sync_ucs: get_password_from_ad failed with %s, retry with reconnect" % (exc,))
-        nt_hash, krb5Key, _ = get_password_from_ad(connector, object['dn'], reconnect=True)
+        nt_hash, _krb5Key, _ = get_password_from_ad(connector, object['dn'], reconnect=True)
 
     if not nt_hash:
         ud.debug(ud.LDAP, ud.INFO, "password_sync_ucs: No password hash could be read from AD")
@@ -608,7 +608,7 @@ def password_sync(connector, key, ucs_object):
                 ud.debug(ud.LDAP, ud.INFO, "password_sync: password expiry for %s is %s" % (ucs_object['dn'], policy))
                 policy_value = policy.get('value', [None])[0]
                 if policy_value:
-                    new_shadowMax = policy_value
+                    new_shadowMax = '' if int(policy_value) == 0 else str(int(policy_value) - 1).encode('ASCII')
                     new_krb5end = time.strftime("%Y%m%d000000Z", time.gmtime(int(time.time()) + (int(policy_value) * 3600 * 24))).encode('ASCII')
 
             # update shadowMax (set to value of univentionPWExpiryInterval, otherwise delete) and
@@ -643,11 +643,11 @@ def password_sync(connector, key, ucs_object):
                 modlist.append(('krb5PasswordEnd', b'', new_krb5end))
             if old_shadowMax:
                 ud.debug(ud.LDAP, ud.INFO, "password_sync: shadowMax in modlist (replace): 0")
-                modlist.append(('shadowMax', old_shadowMax, b'1'))
+                modlist.append(('shadowMax', old_shadowMax, b'0'))
             else:
                 ud.debug(ud.LDAP, ud.INFO, "password_sync: shadowMax in modlist (set): 0")
-                modlist.append(('shadowMax', b'', b'1'))
-            two_days_ago = int(time.time()) - (86400 * 2)
+                modlist.append(('shadowMax', b'', b'0'))
+            two_days_ago = int(time.time()) - (86400 * 2)  # FIXME -1day should be enough
             new_shadowLastChange = str(two_days_ago // 3600 // 24).encode('ASCII')
             if old_shadowLastChange:
                 ud.debug(ud.LDAP, ud.INFO, "password_sync: shadowLastChange in modlist (replace): %s" % new_shadowLastChange)
